@@ -8,13 +8,12 @@ from feltlabs.core.aggregation import (
     remove_noise_models,
     sum_models,
 )
-from feltlabs.core.sklearn_to_json import export_model, import_model
 
 X = [[0], [1], [2]]
 y = [[0, 1, 2], [1, 2, 3], [0, 2, 4]]
 
 
-def test_import_export():
+def test_aggregation():
     model1 = LinearRegression()
     model1.fit(X, y[0])
 
@@ -33,11 +32,11 @@ def test_import_export():
     agg_model = aggregate_models([model1, model3])
     assert np.allclose(agg_model.predict(X), [0, 1.5, 3])
 
-    rand_model1 = random_model(model1)
+    rand_model1 = random_model(model1, 10)
     enc_model1 = sum_models([model1, rand_model1])
     assert not np.allclose(enc_model1.predict(X), y[0])
 
-    rand_model2 = random_model(model2)
+    rand_model2 = random_model(model2, 11)
     enc_model2 = sum_models([model2, rand_model2])
     assert not np.allclose(enc_model2.predict(X), y[1])
 
